## Changelog

Richard de Vos <rdevos72@gmail.com>
fhs_iptv_tools
fhs-iptv-tools

Shortlist to come:
------------------
- searching channels
- selecting channels
- probe selected channels
- save selected to new file
- and lots more

--------------------------------------------------------------
- 0.8.0: initial creation
